@@ -9,7 +9,12 @@ config = Config.getConfig(parentKey='core', key='Logger')
 
 
 import logging
-logging.basicConfig(filename="hackingtools.log", filemode='a', format='%(asctime)s %(levelname)s - %(message)s', datefmt='%Y-%m-%d %H:%M:%S')
+
+path_log = 'hackingtools.log'
+if not Utils.amIdjango(__file__):
+    path_log = os.path.join(os.path.split(os.path.split(os.path.split(os.path.split(__file__)[0])[0])[0])[0], path_log)
+
+logging.basicConfig(filename=path_log, filemode='a', format='%(asctime)s %(levelname)s - %(message)s', datefmt='%Y-%m-%d %H:%M:%S')
 
 __colorama.init()
 
@@ -128,6 +133,14 @@ def printMessage(message, description=None, debug_module=False, debug_core=False
     else:
         msg = '{methodCalledFrom} - {message}'.format(methodCalledFrom=methodCalledFrom, message=message)
 
+    if is_error:
+        logging.critical(msg)
+    if is_info:
+        logging.info(msg)
+    if is_success:
+        logging.debug(msg)
+    if is_warn:
+        logging.warning(msg)
 
     if (color == __Fore.YELLOW or is_warn):
         msg = '{e} - {m}'.format(e=warn_flag, m=msg)
@@ -147,15 +160,6 @@ def printMessage(message, description=None, debug_module=False, debug_core=False
     else:
         __logs__[time_now] = msg
 
-    if is_error:
-        logging.critical(msg)
-    if is_info:
-        logging.info(msg)
-    if is_success:
-        logging.log(msg)
-    if is_warn:
-        logging.warning(msg)
-
     temp_logs_clear = {}
 
     for x in __logs__:
